# Generated by roxygen2: do not edit by hand

S3method(as.pplot,default)
S3method(as.pplot,pplot)
S3method(as.pvarx,default)
S3method(as.pvarx,pvarx)
S3method(as.pvarx,sboot2)
S3method(as.t_D,default)
S3method(as.varx,default)
S3method(as.varx,sboot2)
S3method(as.varx,svarest)
S3method(as.varx,svars)
S3method(as.varx,svecest)
S3method(as.varx,varest)
S3method(as.varx,vec2var)
S3method(fevd,id)
S3method(irf,pvarx)
S3method(irf,varx)
S3method(plot,pplot)
S3method(plot,svarfevd)
S3method(print,coint)
S3method(print,pcoint)
S3method(print,pplot)
S3method(print,pvarx)
S3method(print,rboot)
S3method(print,sboot2)
S3method(print,speci)
S3method(print,varx)
S3method(summary,coint)
S3method(summary,pcoint)
S3method(summary,pid)
S3method(summary,pvarx)
S3method(summary,rboot)
S3method(summary,sboot2)
S3method(summary,varx)
S3method(toLatex,coint)
S3method(toLatex,pcoint)
S3method(toLatex,pid)
S3method(toLatex,sboot2)
export(PP.system)
export(PP.variable)
export(VECM)
export(as.pplot)
export(as.pvarx)
export(as.t_D)
export(as.varx)
export(coint.JO)
export(coint.SL)
export(id.grt)
export(id.iv)
export(pcoint.BR)
export(pcoint.CAIN)
export(pcoint.JO)
export(pcoint.SL)
export(pid.chol)
export(pid.cvm)
export(pid.dc)
export(pid.grt)
export(pid.iv)
export(pvarx.VAR)
export(pvarx.VEC)
export(rboot.normality)
export(sboot.mb)
export(sboot.mg)
export(sboot.pmb)
export(speci.VAR)
export(speci.factors)
import(ggplot2)
import(svars)
import(vars)
importFrom(DEoptim,DEoptim)
importFrom(DEoptim,DEoptim.control)
importFrom(copula,indepTestSim)
importFrom(pbapply,pblapply)
importFrom(reshape2,melt)
importFrom(scales,hue_pal)
importFrom(stats,.lm.fit)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,optim)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,pgamma)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,resid)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,var)
importFrom(steadyICA,W2theta)
importFrom(steadyICA,steadyICA)
importFrom(utils,combn)
importFrom(utils,head)
importFrom(utils,tail)
importFrom(utils,toLatex)
importFrom(vars,Bcoef)
importFrom(vars,vec2var)
